@@ -312,7 +312,7 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
             else:
                 self.g_statview.update()
     def get_pretty_name(self):
-        return const.exercisedata[self.m_exname][0]
+       return string.replace(const.exercisedata[self.m_exname][0], '_', '')
     def _add_auto_new_question_gui(self, box):
         hbox = gu.bHBox(box, gtk.FALSE)
         hbox.set_spacing(gnome.uiconsts.PAD_SMALL)
@@ -394,10 +394,10 @@ class LessonbasedGui(Gui):
     def __init__(self, teacher, window):
         Gui.__init__(self, teacher, window)
     def get_pretty_name(self):
-        if self.get_string('lessoncollection') == 'solfege':
-            return "%s - %s" % (const.exercisedata[self.m_exname][0],
-                                self.get_string('lessonfile'))
-        else:
-            return "%s - %s/%s" % (const.exercisedata[self.m_exname][0],
+       s = string.replace(const.exercisedata[self.m_exname][0], '_', '')
+       if self.get_string('lessoncollection') == 'solfege':
+            return "%s - %s" % (s, self.get_string('lessonfile'))
+       else:
+            return "%s - %s/%s" % (s,
              self.get_string('lessoncollection'), self.get_string('lessonfile'))
 
