@@ -26,14 +26,14 @@ import soundcard
 
 class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
     def on_destroy(self, widget):
-        self.m_app.mainwin.g_config_window.destroy()
-        self.m_app.mainwin.g_config_window = None
+        self.m_app.m_ui.g_config_window.destroy()
+        self.m_app.m_ui.g_config_window = None
     def __init__(self, app):
         gnome.ui.GnomePropertyBox.__init__(self)
         cfg.ConfigUtils.__init__(self, 'configwindow')
         self.m_app = app
         self._is_alive = 0
-        self.connect('apply', self.on_apply)
+        self.__apply_tag = self.connect('apply', self.on_apply)
         self.connect('help', self.on_help)
         self.connect('destroy', self.on_destroy)
         ########
@@ -110,7 +110,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         vbox = gtk.GtkVBox()
         vbox.set_border_width(gnome.uiconsts.PAD)
         self.append_page(vbox, gtk.GtkLabel(_("Gui")))
-       
+ 
         hbox = gu.bHBox(vbox, gtk.FALSE)
         hbox.set_spacing(gnome.uiconsts.PAD)
 
@@ -121,7 +121,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         frame_vbox.set_border_width(gnome.uiconsts.PAD)
         frame.add(frame_vbox)
         frame_hbox = gu.bHBox(frame_vbox)
-        
+ 
         self.g_toolbar_icons = gu.RadioButton(None, _("Icons"), self.on_changed)
         frame_hbox.pack_start(self.g_toolbar_icons, gtk.FALSE)
         self.g_toolbar_text = gu.RadioButton(self.g_toolbar_icons, _("Text"), self.on_changed)
@@ -140,7 +140,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             self.g_toolbar_show.set_active(gtk.TRUE)
         else:
             self.g_toolbar_hide.set_active(gtk.TRUE)
-        
+
         frame = gtk.GtkFrame(_("Navigation toolbar"))
         frame.set_border_width(gnome.uiconsts.PAD)
         hbox.pack_start(frame, gtk.FALSE)
@@ -150,7 +150,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         frame_hbox = gu.bHBox(frame_vbox)
         sep = gtk.GtkHSeparator()
         frame_vbox.pack_start(sep)
-        
+
         self.g_navbar_icons = gu.RadioButton(None, _("Icons"), self.on_changed)
         frame_hbox.pack_start(self.g_navbar_icons, gtk.FALSE)
         self.g_navbar_text = gu.RadioButton(self.g_navbar_icons, _("Text"), self.on_changed)
@@ -213,7 +213,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         self.g_autorepeat_if_wrong = gtk.GtkCheckButton(_("Repeat question if the answer was wrong"))
         self.g_autorepeat_if_wrong.set_active(self.get_bool('config/auto_repeat_question_if_wrong_answer'))
         vbox.pack_start(self.g_autorepeat_if_wrong, gtk.FALSE)
-        
+ 
         self.g_picky_on_new_question.connect('clicked', self.on_changed)
         self.g_autorepeat_if_wrong.connect('clicked', self.on_changed)
 
@@ -241,6 +241,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         self.g_device_entry.set_text(self.get_string('sound/device_file'))
         self.g_synth_num = gtk.GtkSpinButton(gtk.GtkAdjustment(0, 0, 100, 1, 1),
                              digits=0)
+        self.g_synth_num.set_value(self.get_int('sound/synth_num'))
         hbox.pack_start(combo, gtk.FALSE)
         hbox.pack_start(self.g_synth_num, gtk.FALSE)
 
@@ -261,7 +262,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             self.g_device_radio.set_active(gtk.TRUE)
         else:
             self.g_fakesynth_radio.set_active(gtk.TRUE)
-            
+ 
         # checkbox to enable awe support
         self.g_awe_checkbutton = gtk.GtkCheckButton(_("My sound card is Sound Blaster AWE32, AWE64 or pnp32"))
         self.g_awe_checkbutton.set_active(self.get_string('sound/card_info') == 'awe')
@@ -292,18 +293,18 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         card_info = ""
         if pagenum == 0:
             self.set_int('config/slow_bpm', int(self.g_slow_bpm.get_text()))
-            self.set_int('config/default_bpm', 
+            self.set_int('config/default_bpm',
                          int(self.g_default_bpm.get_text()))
-            self.set_int('config/arpeggio_bpm', 
+            self.set_int('config/arpeggio_bpm',
                          int(self.g_arpeggio_bpm.get_text()))
-            self.set_int('config/preferred_instrument', 
+            self.set_int('config/preferred_instrument',
                          self.g_instrsel.m_instrument)
             self.set_int('config/preferred_instrument_velocity',
                          self.g_instrsel.g_velocity.get_value_as_int())
         if pagenum == 1:
             self.set_string('user/lowest_pitch',
                             self.g_lowest_singable.get_value())
-            self.set_string('user/highest_pitch', 
+            self.set_string('user/highest_pitch',
                             self.g_highest_singable.get_value())
             if self.g_sex_male.active:
                 self.set_string('user/sex', 'male')
@@ -311,51 +312,51 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
                 self.set_string('user/sex', 'female')
         if pagenum == 2:
             if self.g_toolbar_text.active:
-                self.m_app.mainwin.g_toolbar.set_style(gtk.TOOLBAR_TEXT)
+                self.m_app.m_ui.g_toolbar.set_style(gtk.TOOLBAR_TEXT)
                 self.set_string('gui/toolbar_style', 'text')
             elif self.g_toolbar_icons.active:
-                self.m_app.mainwin.g_toolbar.set_style(gtk.TOOLBAR_ICONS)
+                self.m_app.m_ui.g_toolbar.set_style(gtk.TOOLBAR_ICONS)
                 self.set_string('gui/toolbar_style', 'icons')
             elif self.g_toolbar_both.active:
-                self.m_app.mainwin.g_toolbar.set_style(gtk.TOOLBAR_BOTH)
+                self.m_app.m_ui.g_toolbar.set_style(gtk.TOOLBAR_BOTH)
                 self.set_string('gui/toolbar_style', 'both')
             if self.g_toolbar_show.active:
-                self.m_app.mainwin.get_dock_item_by_name('main-toolbar').show()
+                self.m_app.m_ui.get_dock_item_by_name('main-toolbar').show()
                 self.set_bool('gui/toolbar_visible', 1)
             else:
                 self.set_bool('gui/toolbar_visible', 0)
-                self.m_app.mainwin.get_dock_item_by_name('main-toolbar').hide()
+                self.m_app.m_ui.get_dock_item_by_name('main-toolbar').hide()
 
             if self.g_navbar_text.active:
-                self.m_app.mainwin.g_navbar.set_style(gtk.TOOLBAR_TEXT)
+                self.m_app.m_ui.g_navbar.set_style(gtk.TOOLBAR_TEXT)
                 self.set_string('gui/navbar_style', 'text')
             elif self.g_navbar_icons.active:
-                self.m_app.mainwin.g_navbar.set_style(gtk.TOOLBAR_ICONS)
+                self.m_app.m_ui.g_navbar.set_style(gtk.TOOLBAR_ICONS)
                 self.set_string('gui/navbar_style', 'icons')
             elif self.g_navbar_both.active:
-                self.m_app.mainwin.g_navbar.set_style(gtk.TOOLBAR_BOTH)
+                self.m_app.m_ui.g_navbar.set_style(gtk.TOOLBAR_BOTH)
                 self.set_string('gui/navbar_style', 'both')
             if self.g_navbar_show.active:
-                self.m_app.mainwin.get_dock_item_by_name('backandforward').show()
+                self.m_app.m_ui.get_dock_item_by_name('backandforward').show()
                 self.set_bool('gui/navbar_visible', 1)
             else:
-                self.m_app.mainwin.get_dock_item_by_name('backandforward').hide()
+                self.m_app.m_ui.get_dock_item_by_name('backandforward').hide()
                 self.set_bool('gui/navbar_visible', 0)
             self.set_bool('gui/mainwin_user_resizeable',
                           self.g_mainwin_user_resizeable.active)
             if self.get_bool('gui/mainwin_user_resizeable'):
-                self.m_app.mainwin.set_policy(0, 1, 0)
+                self.m_app.m_ui.set_policy(0, 1, 0)
             else:
-                self.m_app.mainwin.set_policy(0, 0, 1)
+                self.m_app.m_ui.set_policy(0, 0, 1)
             self.set_string("config/web_browser", self.g_web_browser.get_text())
             self.set_string("config/mua", self.g_mail_program.get_text())
-            d = self.m_app.mainwin.get_dock_item_by_name("Menubar")
+            d = self.m_app.m_ui.get_dock_item_by_name("Menubar")
             self.set_bool('gui/development_menu_visible',
                           self.g_development_menu_visible.active)
             if self.get_bool('gui/development_menu_visible'):
-                self.m_app.mainwin.get_dock_item_by_name("Menubar").children()[0].children()[1].show()
+                self.m_app.m_ui.get_dock_item_by_name("Menubar").children()[0].children()[1].show()
             else:
-                self.m_app.mainwin.get_dock_item_by_name("Menubar").children()[0].children()[1].hide()
+                self.m_app.m_ui.get_dock_item_by_name("Menubar").children()[0].children()[1].hide()
         if pagenum == 3:
             self.set_bool('config/picky_on_new_question', 
                           self.g_picky_on_new_question.active)
@@ -365,7 +366,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             if soundcard.synth:
                 soundcard.synth.close()
             if self.g_midiplayer_radio.active:
-                soundcard.initialise( 
+                soundcard.initialise_external_midiplayer(
                       self.g_midiplayer_entry.get_text())
             elif self.g_device_radio.active:
                 if configureoutput.HAVE_LINUX_AWE_VOICE_H and \
@@ -373,36 +374,34 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
                       card_info = "awe"
                 else:
                      card_info = ""
-                soundcard.initialise(
+                try:
+                    soundcard.initialise_devicefile(
                       self.g_device_entry.get_text(),
                       self.g_synth_num.get_value_as_int(),
                       card_info)
+                except (soundcard.SoundInitException, OSError), e:
+                    self.m_app.popup_sound_init_error_dialog(e)
             elif self.g_fakesynth_radio.active:
                 soundcard.initialise_using_fake_synth(0)
             else:
                 raise "Shit"
             if self.g_midiplayer_radio.active:
                 self.set_string("sound/type", "external-midiplayer")
-                self.set_string("_tmp/type", "external-midiplayer")
             elif self.g_device_radio.active:
                 self.set_string("sound/type", "sequencer-device")
-                self.set_string("_tmp/type", "sequencer-device")
-            elif self.g_fakesynth_radio.active:
-                self.set_string("sound/type", "fake-synth")
-                self.set_string("_tmp/type", "fake-synth")
             else:
-                raise "Shit"
+                assert self.g_fakesynth_radio.active
+                self.set_string("sound/type", "fake-synth")
             self.set_string("sound/device_file", self.g_device_entry.get_text())
-            self.set_string("_tmp/device_file", self.g_device_entry.get_text())
             self.set_string("sound/card_info", card_info)
-            self.set_string("_tmp/card_info", card_info)
-            self.set_int("sound/synth_num", self.g_synth_num.get_value_as_int())
-            self.set_int("_tmp/synth_num", self.g_synth_num.get_value_as_int())
-            self.set_string("sound/commandline", 
+            if soundcard.synth.m_type_major == "OSS":
+                self.set_int("sound/synth_num", soundcard.synth.m_devnum)
+                # we set the spin just in case m_devnum was changed by the
+                # soundcard setup code, if it was out of range
+                self.g_synth_num.set_value(soundcard.synth.m_devnum)
+            self.set_string("sound/commandline",
                             self.g_midiplayer_entry.get_text())
-            self.set_string("_tmp/commandline",
-                            self.g_midiplayer_entry.get_text())
-        if pagenum == -1:        
+        if pagenum == -1:
             pass
 
 
