@@ -133,7 +133,7 @@ class IntervallPianoWidget(PianoKeyboard):
         self.m_marks = {}
     def mark(self, midi_int):
         x, y = self.midi_int_to_key(midi_int)
-        if not self.m_marks.has_key(x, y):
+        if not self.m_marks.has_key((x, y)):
             g = self.m_keyboard.add('group')
             g.connect('event', self.on_event, midi_int)
             self.m_marks[x, y] = g
@@ -154,7 +154,7 @@ class IntervallPianoWidget(PianoKeyboard):
         self.update_now()
     def unmark(self, midi_int):
         x, y = self.midi_int_to_key(midi_int) 
-        if self.m_marks.has_key(x, y):
+        if self.m_marks.has_key((x, y)):
             self.m_marks[x, y].destroy()
             del self.m_marks[x, y]
         else:
