@@ -16,7 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome
-import gu, const, soundcard, mpd, abstract, random
+import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract, random
 import lessonfile, statistics, string
 from i18n import _
 import widgets
@@ -70,7 +70,7 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_music_displayer = mpd.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.g_music_displayer.set_usize(-1, 170)
         self.practise_box.pack_start(self.g_music_displayer)
         
